@@ -132,6 +132,10 @@ class DiscourseErrorUserCreate(Exception):
     pass
 
 
+class DiscourseErrorUserActive(Exception):
+    pass
+
+
 class DiscourseErrorUserPreferences(Exception):
     pass
 
@@ -531,7 +535,7 @@ class Discourse(object):
 
     @staticmethod
     def user_dict2params(user):
-        return {k: v for k, v in user.items() if k in Discourse.user_fields()}
+        return {k: Discourse.value2str(v) for k, v in user.items() if k in Discourse.user_fields()}
 
     @staticmethod
     def user_fields():
@@ -569,7 +573,31 @@ class Discourse(object):
                 raise DiscourseErrorUserCreate(f'{target} failed {r["message"]}')
         else:
             self.d._put(f'/u/{before["username"]}', **target)
+            after = self.user_get(email)
+            if after['active'] != target['active']:
+                _, after = self.user_active(email, target['active'])
+            return before, after
+
+    def user_active(self, email, active):
+        before = self.user_get(email)
+        if before['active'] == active:
+            return before, before
+        if self.args.dry_run:
+            after = copy.deepcopy(before)
+            after['active'] = active
+            return before, after
+        if active == 'true':
+            action = 'activate'
+        elif active == 'false':
+            action = 'deactivate'
+        else:
+            raise DiscourseErrorUserActive(
+                f'active={active} invalid, it must be "true" or "false"')
+        r = self.d._put(f'/admin/users/{before["id"]}/{action}')
+        if r['success']:
             return before, self.user_get(email)
+        else:
+            raise DiscourseErrorUserActive(f'active={active} failed {r["message"]}')
 
     def user_delete(self, email):
         user = self.user_get(email)
