@@ -211,6 +211,70 @@ def test_user_create(test_options, email):
         d.user_delete(email)
 
 
+def test_user_create_active(test_options):
+    email = 'user@example.com'
+    d = DiscourseTest(test_options).connect()
+    try:
+        password = 'dashkeedfakojfiesMob'
+        username = 'MYUSERNAME'
+        kwargs = {
+            'username': username,
+            'password': password,
+            'active': 'false',
+        }
+
+        before0, after0 = d.user_create(email, **kwargs)
+        assert before0 is None
+        assert after0['active'] == 'false'
+
+        kwargs['active'] = 'true'
+        before1, after1 = d.user_create(email, **kwargs)
+        assert before1['active'] == 'false'
+        assert after1['active'] == 'true'
+
+        kwargs['active'] = 'false'
+        before2, after2 = d.user_create(email, **kwargs)
+        assert before2['active'] == 'true'
+        assert after2['active'] == 'false'
+
+    finally:
+        d.user_delete(email)
+
+
+def test_user_active(test_options):
+    email = 'user@example.com'
+    d = DiscourseTest(test_options).connect()
+    try:
+        password = 'dashkeedfakojfiesMob'
+        username = 'MYUSERNAME'
+        kwargs = {
+            'username': username,
+            'password': password,
+            'active': 'true',
+        }
+        _, _ = d.user_create(email, **kwargs)
+
+        d.args.dry_run = True
+        before0, after0 = d.user_active(email, 'false')
+        assert before0['active'] == 'true'
+        assert after0['active'] == 'false'
+
+        d.args.dry_run = False
+        before0, after0 = d.user_active(email, 'false')
+        assert before0['active'] == 'true'
+        assert after0['active'] == 'false'
+
+        before1, after1 = d.user_active(email, 'true')
+        assert before1['active'] == 'false'
+        assert after1['active'] == 'true'
+
+        before2, after2 = d.user_active(email, 'true')
+        assert after1 == before2
+        assert before2 == after2
+    finally:
+        d.user_delete(email)
+
+
 def test_user_duplicate(test_options):
     d = DiscourseTest(test_options).connect()
     first_email = 'someuser@some.com'
@@ -218,12 +282,12 @@ def test_user_duplicate(test_options):
     try:
         password = 'dashkeedfakojfiesMob'
         _, first = d.user_create(first_email, **{
-            'active': True,
+            'active': 'true',
             'username': 'FIRST',
             'password': password,
         })
         _, second = d.user_create(second_email, **{
-            'active': True,
+            'active': 'true',
             'username': 'SECOND',
             'password': password,
         })
@@ -240,7 +304,6 @@ def test_user_name_invalid(test_options):
         password = 'dashkeedfakojfiesMob'
         invalid_username = 'USERNAME'
         kwargs = {
-            'active': True,
             'username': invalid_username,
             'password': password,
         }
@@ -253,7 +316,7 @@ def test_user_preferences_set(test_options):
     email = 'me@example.com'
     try:
         kwargs = {
-            'active': True,
+            'active': 'true',
             'username': 'myusername',
             'password': 'dashkeedfakojfiesMob',
         }
@@ -294,7 +357,7 @@ def test_group_member(test_options):
         password = 'dashkeedfakojfiesMob'
         username = 'MYUSERNAME'
         _, user = d.user_create(email, **{
-            'active': True, 'username': username, 'password': password})
+            'active': 'true', 'username': username, 'password': password})
         _, group = d.group_create(group_name)
 
         #
@@ -393,7 +456,7 @@ def test_category_notifications(test_options):
         password = 'dashkeedfakojfiesMob'
         username = 'MYUSERNAME'
         _, user = d.user_create(email, **{
-            'active': True, 'username': username, 'password': password})
+            'active': 'true', 'username': username, 'password': password})
         _, category = d.category_create(category_name)
 
         level0 = '2'
@@ -455,7 +518,7 @@ def test_message_load(test_options):
         password = 'dashkeedfakojfiesMob'
         username = 'MYUSERNAME'
         _, user = d.user_create(email, **{
-            'active': True, 'username': username, 'password': password})
+            'active': 'true', 'username': username, 'password': password})
         _, category = d.category_create(category_name)
         d.settings_set(email_in='true',
                        log_mail_processing_failures='true',
