@@ -361,7 +361,7 @@ def test_importer_category_settings(test_options, info, verify):
         password = 'dashkeedfakojfiesMob'
         username = 'NONMEMBERNAME'
         _, _ = i.discourse.user_create(nonmember, **{
-            'active': True, 'username': username, 'password': password})
+            'active': 'true', 'username': username, 'password': password})
 
         _, _ = i.importer()
 
